/**
 * Copyright 2013 Peergreen S.A.S.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ow2.easybeans.persistence;

import java.net.URI;

import org.ow2.util.archive.api.IArchive;

/**
 * Defines the interface for analyzing Persistence XML archive.
 * @author Florent Benoit
 */
public interface EZBPersistenceXmlAnalyzer {

    /**
     * Detects and analyze the META-INF/persistence.xml file.
     * @param archive the file to analyze (or directory) in order to find a
     * persistence.xml file.
     * @param classloader the classloader used to load the archive
     * @return a a persistence unit manager
     * @throws PersistenceXmlAnalyzerException if detection or analyze fails.
     */
    EZBPersistenceUnitManager analyzePersistenceXmlFile(final IArchive archive, final ClassLoader classLoader)
            throws PersistenceXmlAnalyzerException;

    /**
     * Analyze the given persistence.xml file.
     * @param persistenceUnitRooUrl the root URL of the persistence unit
     * @param persistenceXMLURI the persistence.xml file to analyze.
     * @param ormXMLURI the orm.xml file to analyze (optional).
     * @param classloader the classloader used to load the archive
     * @return a a persistence unit manager
     * @throws PersistenceXmlAnalyzerException if analyze fails.
     */
    public EZBPersistenceUnitManager analyzePersistenceXmlFile(final URI persistenceUnitRooUrl, final URI persistenceXMLURI, final URI ormXMLURI, final ClassLoader classLoader)
            throws PersistenceXmlAnalyzerException;


}